==============
dask-ndfourier
==============


.. image:: https://img.shields.io/pypi/v/dask-ndfourier.svg
        :target: https://pypi.python.org/pypi/dask-ndfourier
        :alt: PyPI

.. image:: https://anaconda.org/conda-forge/dask-ndfourier/badges/version.svg
        :target: https://anaconda.org/conda-forge/dask-ndfourier
        :alt: conda-forge

.. image:: https://img.shields.io/travis/dask-image/dask-ndfourier/master.svg
        :target: https://travis-ci.org/dask-image/dask-ndfourier
        :alt: Travis CI

.. image:: https://readthedocs.org/projects/dask-ndfourier/badge/?version=latest
        :target: https://dask-ndfourier.readthedocs.io/en/latest/?badge=latest
        :alt: Read the Docs

.. image:: https://coveralls.io/repos/github/dask-image/dask-ndfourier/badge.svg
        :target: https://coveralls.io/github/dask-image/dask-ndfourier
        :alt: Coveralls

.. image:: https://img.shields.io/github/license/dask-image/dask-ndfourier.svg
        :target: ./LICENSE.txt
        :alt: License


A library for using N-D Fourier filter with Dask Arrays


* Free software: BSD 3-Clause
* Documentation: https://dask-ndfourier.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `dask-image/dask-image-cookiecutter`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`dask-image/dask-image-cookiecutter`: https://github.com/dask-image/dask-image-cookiecutter

